@@ -1171,6 +1171,8 @@ void tzset_name(const char * name) {
     lclptr->leapcnt = 0;                /* so, we're off a little */
     lclptr->timecnt = 0;
     lclptr->typecnt = 0;
+    lclptr->charcnt = 0;
+    lclptr->goback = lclptr->goahead = FALSE;
     lclptr->ttis[0].tt_isdst = 0;
     lclptr->ttis[0].tt_gmtoff = 0;
     lclptr->ttis[0].tt_abbrind = 0;
