@@ -2,6 +2,8 @@
 using namespace Rcpp;
 #include <fstream>
 #include "grisu3.h"
+#include "write_connection.h"
+#include <boost/iostreams/stream.hpp> // stream
 
 // Defined later to make copyright clearer
 template <class Stream>
@@ -55,7 +57,7 @@ void stream_delim(Stream& output, const char* string, char delim, const std::str
 
 template <class Stream>
 void stream_delim(Stream& output, const List& df, char delim, const std::string& na,
-                  bool col_names = true, bool append = false, bool bom = false) {
+                  bool col_names = true, bool bom = false) {
   int p = Rf_length(df);
   if (p == 0)
     return;
@@ -83,22 +85,18 @@ void stream_delim(Stream& output, const List& df, char delim, const std::string&
 }
 
 // [[Rcpp::export]]
-std::string stream_delim(const List& df, const std::string& path, char delim, const std::string& na,
-                         bool col_names = true, bool append = false, bool bom = false) {
-
-  if (path == "") {
+std::string stream_delim_(const List& df, RObject connection, char delim, const std::string& na,
+                         bool col_names = true, bool bom = false) {
+  if (connection == R_NilValue) {
     std::ostringstream output;
-
-    stream_delim(output, df, delim, na, col_names, append, bom);
+    stream_delim(output, df, delim, na, col_names, bom);
     return output.str();
   } else {
-    std::ofstream output(path.c_str(), append ? std::ofstream::app : std::ofstream::trunc);
-    if (output.fail()) {
-      stop("Failed to open '%s'.", path);
-    }
-    stream_delim(output, df, delim, na, col_names, append, bom);
-    return "";
+    boost::iostreams::stream<connection_sink> output(connection);
+    stream_delim(output, df, delim, na, col_names, bom);
   }
+
+  return "";
 }
 
 // =============================================================================
